pub enum ExampleCodeType {
CodeCapacityRepetitionCode,
PhenomenologicalRepetitionCode,
CircuitLevelRepetitionCode,
CodeCapacityPlanarCode,
PhenomenologicalPlanarCode,
PhenomenologicalPlanarCodeParallel,
CircuitLevelPlanarCode,
CircuitLevelPlanarCodeParallel,
ErrorPatternReader,
CodeCapacityRotatedCode,
PhenomenologicalRotatedCode,
QECPlaygroundCode,
}Expand description
note that these code type is only for example, to test and demonstrate the correctness of the algorithm, but not for real QEC simulation; for real simulation, please refer to https://github.com/yuewuo/QEC-Playground
Variants
CodeCapacityRepetitionCode
quantum repetition code with perfect stabilizer measurement
PhenomenologicalRepetitionCode
quantum repetition code with phenomenological noise model
CircuitLevelRepetitionCode
quantum repetition code with circuit-level noise model
CodeCapacityPlanarCode
planar surface code with perfect stabilizer measurement
PhenomenologicalPlanarCode
planar surface code with phenomenological noise model
PhenomenologicalPlanarCodeParallel
parallel version
CircuitLevelPlanarCode
planar surface code with circuit-level noise model
CircuitLevelPlanarCodeParallel
parallel version
ErrorPatternReader
read from error pattern file, generated using option --primal-dual-type error-pattern-logger
CodeCapacityRotatedCode
rotated surface code with perfect stabilizer measurement
PhenomenologicalRotatedCode
rotated surface code with phenomenological noise model
QECPlaygroundCode
code constructed by QEC-Playground, pass configurations using --code-config
Implementations