pub enum PartitionStrategy {
None,
CodeCapacityPlanarCodeVerticalPartitionHalf,
CodeCapacityPlanarCodeVerticalPartitionFour,
CodeCapacityRepetitionCodePartitionHalf,
PhenomenologicalPlanarCodeTimePartition,
PhenomenologicalRotatedCodeTimePartition,
}Variants
None
no partition
CodeCapacityPlanarCodeVerticalPartitionHalf
partition a planar code into top half and bottom half
CodeCapacityPlanarCodeVerticalPartitionFour
partition a planar code into 4 pieces: top left and right, bottom left and right
CodeCapacityRepetitionCodePartitionHalf
partition a repetition code into left and right half
PhenomenologicalPlanarCodeTimePartition
partition a phenomenological (or circuit-level) planar code with time axis
PhenomenologicalRotatedCodeTimePartition
partition a phenomenological (or circuit-level) rotated code with time axis
Implementations
Sourceimpl PartitionStrategy
impl PartitionStrategy
pub fn build( &self, code: &mut dyn ExampleCode, d: VertexNum, noisy_measurements: VertexNum, partition_config: Value, ) -> (SolverInitializer, PartitionConfig)