pub enum Verifier {
None,
BlossomV,
FusionSerial,
}Variants
None
disable verifier
BlossomV
use blossom V library to verify the correctness of result
FusionSerial
use the serial version of fusion algorithm to verify the correctness of result
Implementations
Sourceimpl Verifier
impl Verifier
pub fn build(&self, initializer: &SolverInitializer) -> Box<dyn ResultVerifier>