BenchmarkParameters

Struct BenchmarkParameters 

pub struct BenchmarkParameters {
Show 20 fields pub d: VertexNum, pub p: f64, pub pe: f64, pub noisy_measurements: VertexNum, pub max_half_weight: Weight, pub code_type: ExampleCodeType, pub code_config: String, pub enable_visualizer: bool, pub visualizer_filename: String, pub print_syndrome_pattern: bool, pub verifier: Verifier, pub total_rounds: usize, pub primal_dual_type: PrimalDualType, pub primal_dual_config: String, pub partition_strategy: PartitionStrategy, pub partition_config: String, pub pb_message: String, pub use_deterministic_seed: bool, pub benchmark_profiler_output: Option<String>, pub starting_iteration: usize,
}

Fields

d: VertexNum

code distance

p: f64

physical error rate: the probability of each edge to

pe: f64

rounds of noisy measurement, valid only when multiple rounds

noisy_measurements: VertexNum

rounds of noisy measurement, valid only when multiple rounds

max_half_weight: Weight

maximum half weight of edges

code_type: ExampleCodeType

example code type

code_config: String

the configuration of the code builder

enable_visualizer: bool

logging to the default visualizer file at visualize/data/visualizer.json

visualizer_filename: String

visualizer file at visualize/data/<visualizer_filename.json>

print_syndrome_pattern: bool

print syndrome patterns

verifier: Verifier

the method to verify the correctness of the decoding result

total_rounds: usize

the number of iterations to run

primal_dual_type: PrimalDualType

select the combination of primal and dual module

primal_dual_config: String

the configuration of primal and dual module

partition_strategy: PartitionStrategy

partition strategy

partition_config: String

the configuration of the partition strategy

pb_message: String

message on the progress bar

use_deterministic_seed: bool

use deterministic seed for debugging purpose

benchmark_profiler_output: Option<String>

the benchmark profile output file path

starting_iteration: usize

skip some iterations, useful when debugging