DualModuleParallel

Struct DualModuleParallel 

pub struct DualModuleParallel<SerialModule: DualModuleImpl + Send + Sync> {
    pub units: Vec<ArcManualSafeLock<DualModuleParallelUnit<SerialModule>>>,
    pub config: DualModuleParallelConfig,
    pub partition_info: Arc<PartitionInfo>,
    pub thread_pool: Arc<ThreadPool>,
    pub empty_sync_request: Vec<SyncRequest>,
}

Fields

units: Vec<ArcManualSafeLock<DualModuleParallelUnit<SerialModule>>>

the basic wrapped serial modules at the beginning, afterwards the fused units are appended after them

config: DualModuleParallelConfig

local configuration

partition_info: Arc<PartitionInfo>

partition information generated by the config

thread_pool: Arc<ThreadPool>

thread pool used to execute async functions in parallel

empty_sync_request: Vec<SyncRequest>

an empty sync requests queue just to implement the trait

Implementations

Source

impl<SerialModule: DualModuleImpl + Send + Sync> DualModuleParallel<SerialModule>

pub fn new_config( initializer: &SolverInitializer, partition_info: &PartitionInfo, config: DualModuleParallelConfig, ) -> Self

recommended way to create a new instance, given a customized configuration

pub fn find_active_ancestor( &self, dual_node_ptr: &DualNodePtr, ) -> DualModuleParallelUnitPtr<SerialModule>

find the active ancestor to handle this dual node (should be unique, i.e. any time only one ancestor is active)

pub fn find_active_ancestor_option( &self, dual_node_ptr: &DualNodePtr, ) -> Option<DualModuleParallelUnitPtr<SerialModule>>

pub fn static_fuse_all(&mut self)

statically fuse them all, may be called at any state (meaning each unit may not necessarily be solved locally)