DualModuleParallelConfig

Struct DualModuleParallelConfig 

pub struct DualModuleParallelConfig {
    pub thread_pool_size: usize,
    pub edges_in_fusion_unit: bool,
    pub enable_parallel_execution: bool,
}

Fields

thread_pool_size: usize

enable async execution of dual operations; only used when calling top-level operations, not used in individual units

edges_in_fusion_unit: bool

strategy of edges placement: if edges are placed in the fusion unit, it’s good for software implementation because there are no duplicate edges and no unnecessary vertices in the descendant units. On the other hand, it’s not very favorable if implemented on hardware: the fusion unit usually contains a very small amount of vertices and edges for the interfacing between two blocks, but maintaining this small graph may consume additional hardware resources and increase the decoding latency. I want the algorithm to finally work on the hardware efficiently so I need to verify that it does work by holding all the fusion unit’s owned vertices and edges in the descendants, although usually duplicated.

enable_parallel_execution: bool

enable parallel execution of a fused dual module