DualModuleParallelUnit

Struct DualModuleParallelUnit 

pub struct DualModuleParallelUnit<SerialModule: DualModuleImpl + Send + Sync> {
Show 14 fields pub unit_index: usize, pub partition_info: Arc<PartitionInfo>, pub partition_unit: PartitionUnitPtr, pub is_active: bool, pub whole_range: VertexRange, pub owning_range: VertexRange, pub extra_descendant_mirrored_vertices: HashSet<VertexIndex>, pub serial_module: SerialModule, pub children: Option<(DualModuleParallelUnitWeak<SerialModule>, DualModuleParallelUnitWeak<SerialModule>)>, pub parent: Option<DualModuleParallelUnitWeak<SerialModule>>, pub elevated_dual_nodes: PtrWeakHashSet<DualNodeWeak>, pub empty_sync_request: Vec<SyncRequest>, pub enable_parallel_execution: bool, pub has_active_node: bool,
}

Fields

unit_index: usize

the index

partition_info: Arc<PartitionInfo>

partition information generated by the config

partition_unit: PartitionUnitPtr

information shared with serial module

is_active: bool

whether it’s active or not; some units are “placeholder” units that are not active until they actually fuse their children

whole_range: VertexRange

the vertex range of this parallel unit consists of all the owning_range of its descendants

owning_range: VertexRange

the vertices owned by this unit, note that owning_range is a subset of whole_range

extra_descendant_mirrored_vertices: HashSet<VertexIndex>

the vertices that are mirrored outside of whole_range, in order to propagate a vertex’s sync event to every unit that mirrors it

serial_module: SerialModule

the owned serial dual module

children: Option<(DualModuleParallelUnitWeak<SerialModule>, DualModuleParallelUnitWeak<SerialModule>)>

left and right children dual modules

parent: Option<DualModuleParallelUnitWeak<SerialModule>>

parent dual module

elevated_dual_nodes: PtrWeakHashSet<DualNodeWeak>

elevated dual nodes: whose descendent not on the representative path of a dual node

empty_sync_request: Vec<SyncRequest>

an empty sync requests queue just to implement the trait

enable_parallel_execution: bool

run things in thread pool

has_active_node: bool

whether any descendant unit has active dual node

Implementations

Source

impl<SerialModule: DualModuleImpl + Send + Sync> DualModuleParallelUnit<SerialModule>

pub fn static_fuse(&mut self)

statically fuse the children of this unit

pub fn fuse( &mut self, parent_interface: &DualModuleInterfacePtr, children_interfaces: (&DualModuleInterfacePtr, &DualModuleInterfacePtr), )

fuse the children of this unit and also fuse the interfaces of them

pub fn iterative_bias_dual_node_index(&mut self, bias: NodeIndex)

pub fn is_vertex_in_descendant(&self, vertex_index: VertexIndex) -> bool

if any descendant unit mirror or own the vertex

pub fn elevated_dual_nodes_contains_any(&self, nodes: &[DualNodePtr]) -> bool

check if elevated_dual_nodes contains any dual node in the list