pub struct Interface {
pub interface_id: usize,
pub data: Weak<InterfaceData>,
}Expand description
interface between dual modules, consisting of a list of nodes of virtual nodes that sits on different modules
Fields
interface_id: usizeunique interface id for ease of zero-cost switching
data: Weak<InterfaceData>link to interface data