pub struct InterfaceData {
pub possession_modules: Vec<DualModuleSerialWeak>,
pub interfacing_vertices: Vec<Vec<VertexWeak>>,
}Expand description
interface consists of several vertices; each vertex exists as a virtual vertex in several different serial dual modules. each virtual vertex exists in at most one interface
Fields
possession_modules: Vec<DualModuleSerialWeak>the serial dual modules that processes these virtual vertices,
interfacing_vertices: Vec<Vec<VertexWeak>>the virtual vertices references in different modules, [idx of serial dual module] [idx of interfacing vertex]