DualModuleSerial

Struct DualModuleSerial 

pub struct DualModuleSerial {
Show 13 fields pub vertices: Vec<VertexPtr>, pub nodes: Vec<Option<DualNodeInternalPtr>>, pub nodes_length: usize, pub edges: Vec<EdgePtr>, pub active_timestamp: FastClearTimestamp, pub vertex_num: VertexNum, pub edge_num: usize, pub owning_range: VertexRange, pub unit_module_info: Option<UnitModuleInfo>, pub active_list: Vec<DualNodeInternalWeak>, pub edge_modifier: EdgeWeightModifier, pub edge_dedup_timestamp: FastClearTimestamp, pub sync_requests: Vec<SyncRequest>, /* private fields */
}

Fields

vertices: Vec<VertexPtr>

all vertices including virtual ones

nodes: Vec<Option<DualNodeInternalPtr>>

nodes internal information

nodes_length: usize

current nodes length, to enable constant-time clear operation

edges: Vec<EdgePtr>

keep edges, which can also be accessed in Self::vertices

active_timestamp: FastClearTimestamp

current timestamp

vertex_num: VertexNum

the number of all vertices (including those partitioned into other serial modules)

edge_num: usize

the number of all edges (including those partitioned into other serial modules)

owning_range: VertexRange

vertices exclusively owned by this module, useful when partitioning the decoding graph into multiple DualModuleSerial

unit_module_info: Option<UnitModuleInfo>

module information when used as a component in the partitioned dual module

active_list: Vec<DualNodeInternalWeak>

maintain an active list to optimize for average cases: most defect vertices have already been matched, and we only need to work on a few remained; note that this list may contain deleted node as well as duplicate nodes

edge_modifier: EdgeWeightModifier

remember the edges that’s modified by erasures

edge_dedup_timestamp: FastClearTimestamp

deduplicate edges in the boundary, helpful when the decoding problem is partitioned

sync_requests: Vec<SyncRequest>

temporary list of synchronize requests, i.e. those propagating into the mirrored vertices; should always be empty when not partitioned, i.e. serial version

Implementations

Source

impl DualModuleSerial

pub fn hard_clear_graph(&mut self)

hard clear all growth (manual call not recommended due to performance drawback)

pub fn clear_graph(&mut self)

soft clear all growth

pub fn sanity_check(&self) -> Result<(), String>

do a sanity check of if all the nodes are in consistent state

Source

impl DualModuleSerial

pub fn get_dual_node_index(&self, dual_node_ptr: &DualNodePtr) -> Option<usize>

get the local index of a dual node, thus has usize type

pub fn get_vertex_index(&self, vertex_index: VertexIndex) -> Option<usize>

get the local index of a vertex, thus has usize type

pub fn get_dual_node_internal_ptr( &self, dual_node_ptr: &DualNodePtr, ) -> DualNodeInternalPtr

pub fn get_dual_node_internal_ptr_optional( &self, dual_node_ptr: &DualNodePtr, ) -> Option<DualNodeInternalPtr>

dual node ptr may not hold in this module

pub fn get_otherwise_add_dual_node( &mut self, dual_node_ptr: &DualNodePtr, dual_variable: Weight, ) -> DualNodeInternalPtr

possibly add dual node only when sync_event is provided

pub fn prepare_dual_node_growth_single( &mut self, dual_node_ptr: &DualNodePtr, is_grow: bool, ) -> bool

this is equivalent to DualModuleSerial::prepare_dual_node_growth when there are no 0 weight edges, but when it encounters zero-weight edges, it will report true

pub fn prepare_dual_node_growth( &mut self, dual_node_ptr: &DualNodePtr, is_grow: bool, )

adjust the boundary of each dual node to fit into the need of growing (length > 0) or shrinking (length < 0)