pub struct CodeEdge {
pub vertices: (VertexIndex, VertexIndex),
pub p: f64,
pub pe: f64,
pub half_weight: Weight,
pub is_erasure: bool,
}Expand description
Edge flips the measurement result of two vertices
Fields
vertices: (VertexIndex, VertexIndex)the two vertices incident to this edge
p: f64probability of flipping the results of these two vertices; do not set p to 0 to remove edge: if desired, create a new code type
pe: f64probability of having a reported event of error on this edge
half_weight: Weightthe integer weight of this edge
is_erasure: boolwhether this edge is erased
Implementations
Sourceimpl CodeEdge
impl CodeEdge
pub fn new(a: VertexIndex, b: VertexIndex) -> Self