pub struct ErrorPatternReader {
pub vertices: Vec<CodeVertex>,
pub edges: Vec<CodeEdge>,
pub syndrome_patterns: Vec<SyndromePattern>,
pub defect_index: usize,
pub cyclic_syndrome: bool,
}Expand description
read from file, including the error patterns; the point is to avoid bad cache performance, because generating random error requires iterating over a large memory space, invalidating all cache. also, this can reduce the time of decoding by prepare the data before hand and could be shared between different partition configurations
Fields
vertices: Vec<CodeVertex>vertices in the code
edges: Vec<CodeEdge>nearest-neighbor edges in the decoding graph
syndrome_patterns: Vec<SyndromePattern>pre-generated syndrome patterns
defect_index: usizecursor of current errors
cyclic_syndrome: boolImplementations