pub struct PhenomenologicalRotatedCodeTimePartition {
pub d: VertexNum,
pub noisy_measurements: VertexNum,
pub partition_num: usize,
pub enable_tree_fusion: bool,
pub maximum_tree_leaf_size: usize,
}Expand description
evenly partition along the time axis
Fields
d: VertexNumcode distance
noisy_measurements: VertexNumrounds of noisy measurement, valid only when multiple rounds
partition_num: usizethe number of partition
enable_tree_fusion: boolenable tree fusion (to minimize latency but incur log(partition_num) more memory copy)
maximum_tree_leaf_size: usizemaximum amount of tree leaf; if the total partition is greater than this, it will be cut into multiple regions and each region is a separate tree; those trees are then fused sequentially
Implementations