pub struct SubGraphBuilder {
pub vertex_num: VertexNum,
pub complete_graph: CompleteGraph,
pub subgraph: BTreeSet<EdgeIndex>,
/* private fields */
}Expand description
build a subgraph based on minimum-weight paths between matched pairs
Fields
vertex_num: VertexNumnumber of vertices
complete_graph: CompleteGraphan instance of complete graph to compute minimum-weight path between any pair of vertices
subgraph: BTreeSet<EdgeIndex>current subgraph, assuming edges are not very much
Implementations
Sourceimpl SubGraphBuilder
impl SubGraphBuilder
pub fn new(initializer: &SolverInitializer) -> Self
pub fn clear(&mut self)
Sourcepub fn load_erasures(&mut self, erasures: &[EdgeIndex])
pub fn load_erasures(&mut self, erasures: &[EdgeIndex])
temporarily set some edges to 0 weight, and when it resets, those edges will be reverted back to the original weight
pub fn load_dynamic_weights(&mut self, dynamic_weights: &[(EdgeIndex, Weight)])
Sourcepub fn load_perfect_matching(&mut self, perfect_matching: &PerfectMatching)
pub fn load_perfect_matching(&mut self, perfect_matching: &PerfectMatching)
load perfect matching to the subgraph builder
pub fn load_subgraph(&mut self, subgraph: &[EdgeIndex])
Sourcepub fn add_matching(&mut self, vertex_1: VertexIndex, vertex_2: VertexIndex)
pub fn add_matching(&mut self, vertex_1: VertexIndex, vertex_2: VertexIndex)
add a matching, finding the minimum path and XOR them into the subgraph (if adding the same pair twice, they will cancel each other)
Sourcepub fn total_weight(&self) -> Weight
pub fn total_weight(&self) -> Weight
get the total weight of the subgraph
Sourcepub fn get_subgraph(&self) -> Vec<EdgeIndex> ⓘ
pub fn get_subgraph(&self) -> Vec<EdgeIndex> ⓘ
get subgraph as a vec