pub struct PrimalModuleParallelConfig {
pub thread_pool_size: usize,
pub debug_sequential: bool,
pub prioritize_base_partition: bool,
pub interleaving_base_fusion: usize,
pub pin_threads_to_cores: bool,
pub streaming_decode_mock_measure_interval: Option<f64>,
pub streaming_decode_use_spin_lock: bool,
pub max_tree_size: usize,
}Fields
thread_pool_size: usizeenable async execution of dual operations; only used when calling top-level operations, not used in individual units
debug_sequential: booldebug by sequentially run the fusion tasks, user must enable this for visualizer to work properly during the execution
prioritize_base_partition: boolschedule base partition tasks in the front
interleaving_base_fusion: usizepin_threads_to_cores: boolpin threads to cores sequentially
streaming_decode_mock_measure_interval: Option<f64>streaming decode mocker
streaming_decode_use_spin_lock: boolstreaming decoder using spin lock instead of threads.sleep to avoid context switch
max_tree_size: usizemax tree size for the serial modules, for faster speed at the cost of less accuracy