pub struct AlternatingTreeNode {
pub root: PrimalNodeInternalWeak,
pub parent: Option<(PrimalNodeInternalWeak, DualNodeWeak)>,
pub children: Vec<(PrimalNodeInternalWeak, DualNodeWeak)>,
pub depth: usize,
pub tree_size: Option<NonZeroUsize>,
}Fields
root: PrimalNodeInternalWeakthe root of an alternating tree
parent: Option<(PrimalNodeInternalWeak, DualNodeWeak)>the parent in the alternating tree, note that root doesn’t have a parent; together with a child of blossom that touches parent, used to create blossom and expand perfect matching
children: Vec<(PrimalNodeInternalWeak, DualNodeWeak)>the children in the alternating tree, note that odd depth can only have exactly one child; together with a child of blossom that touches each child node in the tree, used to create blossom and expand perfect matching
depth: usizethe depth in the alternating tree, root has 0 depth
tree_size: Option<NonZeroUsize>the number of children in the tree; only the root has this variable.