pub struct PartitionUnit {
pub unit_index: usize,
pub enabled: bool,
}Expand description
a general partition unit that could contain mirrored vertices
Fields
unit_index: usizeunit index
enabled: boolwhether it’s enabled; when disabled, the mirrored vertices behaves just like virtual vertices