pub struct Visualizer {
pub snapshots: Vec<String>,
/* private fields */
}Fields
snapshots: Vec<String>names of the snapshots
Implementations
Sourceimpl Visualizer
impl Visualizer
Sourceimpl Visualizer
impl Visualizer
pub fn incremental_save(&mut self, name: String, value: Value) -> Result<()>
Sourcepub fn snapshot_combined(
&mut self,
name: String,
fusion_algorithms: Vec<&dyn FusionVisualizer>,
) -> Result<()>
pub fn snapshot_combined( &mut self, name: String, fusion_algorithms: Vec<&dyn FusionVisualizer>, ) -> Result<()>
append another snapshot of the fusion type, and also update the file in case
Sourcepub fn snapshot(
&mut self,
name: String,
fusion_algorithm: &impl FusionVisualizer,
) -> Result<()>
pub fn snapshot( &mut self, name: String, fusion_algorithm: &impl FusionVisualizer, ) -> Result<()>
append another snapshot of the fusion type, and also update the file in case
pub fn snapshot_combined_value( &mut self, name: String, values: Vec<Value>, ) -> Result<()>
pub fn snapshot_value(&mut self, name: String, value: Value) -> Result<()>