pub struct BenchmarkParameters {Show 20 fields
pub d: VertexNum,
pub p: f64,
pub pe: f64,
pub noisy_measurements: VertexNum,
pub max_half_weight: Weight,
pub code_type: ExampleCodeType,
pub code_config: String,
pub enable_visualizer: bool,
pub visualizer_filename: String,
pub print_syndrome_pattern: bool,
pub verifier: Verifier,
pub total_rounds: usize,
pub primal_dual_type: PrimalDualType,
pub primal_dual_config: String,
pub partition_strategy: PartitionStrategy,
pub partition_config: String,
pub pb_message: String,
pub use_deterministic_seed: bool,
pub benchmark_profiler_output: Option<String>,
pub starting_iteration: usize,
}Fields
d: VertexNumcode distance
p: f64physical error rate: the probability of each edge to
pe: f64rounds of noisy measurement, valid only when multiple rounds
noisy_measurements: VertexNumrounds of noisy measurement, valid only when multiple rounds
max_half_weight: Weightmaximum half weight of edges
code_type: ExampleCodeTypeexample code type
code_config: Stringthe configuration of the code builder
enable_visualizer: boollogging to the default visualizer file at visualize/data/visualizer.json
visualizer_filename: Stringvisualizer file at visualize/data/<visualizer_filename.json>
print_syndrome_pattern: boolprint syndrome patterns
verifier: Verifierthe method to verify the correctness of the decoding result
total_rounds: usizethe number of iterations to run
primal_dual_type: PrimalDualTypeselect the combination of primal and dual module
primal_dual_config: Stringthe configuration of primal and dual module
partition_strategy: PartitionStrategypartition strategy
partition_config: Stringthe configuration of the partition strategy
pb_message: Stringmessage on the progress bar
use_deterministic_seed: booluse deterministic seed for debugging purpose
benchmark_profiler_output: Option<String>the benchmark profile output file path
starting_iteration: usizeskip some iterations, useful when debugging