pub struct PrimalModuleParallel {
pub units: Vec<PrimalModuleParallelUnitPtr>,
pub config: PrimalModuleParallelConfig,
pub partition_info: Arc<PartitionInfo>,
pub thread_pool: Arc<ThreadPool>,
pub last_solve_start_time: ArcRwLock<Instant>,
}Fields
units: Vec<PrimalModuleParallelUnitPtr>the basic wrapped serial modules at the beginning, afterwards the fused units are appended after them
config: PrimalModuleParallelConfiglocal configuration
partition_info: Arc<PartitionInfo>partition information generated by the config
thread_pool: Arc<ThreadPool>thread pool used to execute async functions in parallel
last_solve_start_time: ArcRwLock<Instant>the time of calling PrimalModuleParallel::parallel_solve_step_callback method
Implementations
Sourceimpl PrimalModuleParallel
impl PrimalModuleParallel
Sourcepub fn new_config(
initializer: &SolverInitializer,
partition_info: &PartitionInfo,
config: PrimalModuleParallelConfig,
) -> Self
pub fn new_config( initializer: &SolverInitializer, partition_info: &PartitionInfo, config: PrimalModuleParallelConfig, ) -> Self
recommended way to create a new instance, given a customized configuration
Sourceimpl PrimalModuleParallel
impl PrimalModuleParallel
pub fn parallel_solve<DualSerialModule: DualModuleImpl + Send + Sync>( &mut self, syndrome_pattern: &SyndromePattern, parallel_dual_module: &DualModuleParallel<DualSerialModule>, )
pub fn parallel_solve_visualizer<DualSerialModule: DualModuleImpl + Send + Sync + FusionVisualizer>( &mut self, syndrome_pattern: &SyndromePattern, parallel_dual_module: &DualModuleParallel<DualSerialModule>, visualizer: Option<&mut Visualizer>, )
pub fn parallel_solve_step_callback<DualSerialModule: DualModuleImpl + Send + Sync, F>(
&mut self,
syndrome_pattern: &SyndromePattern,
parallel_dual_module: &DualModuleParallel<DualSerialModule>,
callback: F,
)where
F: FnMut(&DualModuleInterfacePtr, &DualModuleParallelUnit<DualSerialModule>, &PrimalModuleSerialPtr, Option<&GroupMaxUpdateLength>) + Send + Sync,