pub struct PrimalModuleParallelUnit {
pub unit_index: usize,
pub interface_ptr: DualModuleInterfacePtr,
pub partition_info: Arc<PartitionInfo>,
pub is_active: bool,
pub serial_module: PrimalModuleSerialPtr,
pub children: Option<(PrimalModuleParallelUnitWeak, PrimalModuleParallelUnitWeak)>,
pub parent: Option<PrimalModuleParallelUnitWeak>,
pub event_time: Option<PrimalModuleParallelUnitEventTime>,
pub streaming_decode_mocker: Option<StreamingDecodeMocker>,
}Fields
unit_index: usizethe index
interface_ptr: DualModuleInterfacePtrthe dual module interface, for constant-time clear
partition_info: Arc<PartitionInfo>partition information generated by the config
is_active: boolwhether it’s active or not; some units are “placeholder” units that are not active until they actually fuse their children
serial_module: PrimalModuleSerialPtrthe owned serial primal module
children: Option<(PrimalModuleParallelUnitWeak, PrimalModuleParallelUnitWeak)>left and right children dual modules
parent: Option<PrimalModuleParallelUnitWeak>parent dual module
event_time: Option<PrimalModuleParallelUnitEventTime>record the time of events
streaming_decode_mocker: Option<StreamingDecodeMocker>streaming decode mocker, if exists, base partition will wait until specified time and then start decoding
Implementations
Sourceimpl PrimalModuleParallelUnit
impl PrimalModuleParallelUnit
Sourcepub fn fuse<DualSerialModule: DualModuleImpl + Send + Sync>(
&mut self,
dual_unit: &mut DualModuleParallelUnit<DualSerialModule>,
)
pub fn fuse<DualSerialModule: DualModuleImpl + Send + Sync>( &mut self, dual_unit: &mut DualModuleParallelUnit<DualSerialModule>, )
fuse two units together, by copying the right child’s content into the left child’s content and resolve index;
note that this operation doesn’t update on the dual module, call Self::break_matching_with_mirror if needed
Sourcepub fn break_matching_with_mirror(
&mut self,
dual_module: &mut impl DualModuleImpl,
)
pub fn break_matching_with_mirror( &mut self, dual_module: &mut impl DualModuleImpl, )
break the matched pairs of interface vertices