pub struct PartitionedSolverInitializer {
pub unit_index: usize,
pub vertex_num: VertexNum,
pub edge_num: usize,
pub owning_range: VertexRange,
pub owning_interface: Option<PartitionUnitWeak>,
pub interfaces: Vec<(PartitionUnitWeak, Vec<(VertexIndex, bool)>)>,
pub weighted_edges: Vec<(VertexIndex, VertexIndex, Weight, EdgeIndex)>,
pub virtual_vertices: Vec<VertexIndex>,
}Fields
unit_index: usizeunit index
vertex_num: VertexNumthe number of all vertices (including those partitioned into other serial modules)
edge_num: usizethe number of all edges (including those partitioned into other serial modules)
owning_range: VertexRangevertices exclusively owned by this partition; this part must be a continuous range
owning_interface: Option<PartitionUnitWeak>applicable when all the owning vertices are partitioned (i.e. this belongs to a fusion unit)
interfaces: Vec<(PartitionUnitWeak, Vec<(VertexIndex, bool)>)>if applicable, parent interface comes first, then the grandparent interface, … note that some ancestor might be skipped because it has no mirrored vertices; we skip them because if the partition is in a chain, most of them would only have to know two interfaces on the left and on the right; nothing else necessary. (unit_index, list of vertices owned by this ancestor unit and should be mirrored at this partition and whether it’s virtual)
weighted_edges: Vec<(VertexIndex, VertexIndex, Weight, EdgeIndex)>weighted edges, where the first vertex index is within the range [vertex_index_bias, vertex_index_bias + vertex_num) and the second is either in [vertex_index_bias, vertex_index_bias + vertex_num) or inside
virtual_vertices: Vec<VertexIndex>the virtual vertices